@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
-__version__ = '1.5.1'
+__version__ = '1.6'
 __title__ = 'api4jenkins'
-__description__ = 'Jenkins REST API client'
+__description__ = 'Jenkins Python Client'
 __url__ = 'https://github.com/joelee2012/api4jenkins'
 __author__ = 'Joe Lee'
 __author_email__ = 'lj_2005@163.com'
